from pytiers.core import Point, PitchTier, DurationTier, parameters
from pytiers.utils import read_tier